@@ -16,7 +16,6 @@ $STEP = 300;
 $RUNS = 12*24*30*6;
 $GRUNS = 20;
 $RRD = "piped-demo.rrd";
-$GIF = "piped-demo.gif";
 $PNG = "piped-demo.png";
 
 # some magic to find the correct rrdtol executable
@@ -67,42 +66,6 @@ printf "-- performance analysis Update test\n".
 print "\n";
 # creating some graphs
 
-print "* Creating $GRUNS GIF graphs: $GIF\n\n";
-$now = time;
-for ($i=0;$i<$GRUNS;$i++) {
-RRDp::cmd "graph $GIF ", "--title 'Test GRAPH' ",
-	"--height 150 --vertical-label 'Dummy Units' ".
-	"--start now".(-$RUNS*$STEP),
-	"--color ARROW#bfbfbf",
-        "DEF:alpha=$RRD:in:AVERAGE",
-        "DEF:beta=$RRD:out:AVERAGE",
-        "CDEF:calc=alpha,beta,+,1.5,/",
-        "AREA:alpha#0022e9:Alpha",
-        "STACK:beta#00b871:Beta",
-        "STACK:calc#ff0091:Calc\\j",
-	"PRINT:alpha:AVERAGE:'Average Alpha\\: %1.2lf %S'",
-	"PRINT:alpha:MIN:'Min Alpha\\: %1.2lf %S'",
-	"PRINT:alpha:MAX:'Max Alpha\\: %1.2lf %S'",
-	"GPRINT:calc:AVERAGE:'Average calc\\: %1.2lf %S\\r'",
-	"GPRINT:calc:MIN:'Min calc\\: %1.2lf %S'",
-	"GPRINT:calc:MAX:'Max calc\\: %1.2lf %S'",
-        "VRULE:".($now-3600)."#008877:'60 Minutes ago'",
-        "COMMENT:'\\s'",
-        "COMMENT:'Graph created on: ".localtime(time())."\\c'";
-
-$answer = RRDp::read;
-}
-($user2,$sys2,$real2) =  ($RRDp::user,$RRDp::sys,$RRDp::real);
-
-print "ANSWER:\n$$answer";
-
-printf "\n-- average Time for one Graph\n".
-       "   usr/grf: %1.5fs sys/grf: %1.5fs real/grf: %1.5fs   graphs/sec: %1.2f\n",
-  ($user2-$user1)/$GRUNS, 
-  ($sys2-$sys1)/$GRUNS, 
-  ($real2-$real1)/$GRUNS, 
-  $GRUNS/($real2-$real1);
-
 print "\n\n* Creating $GRUNS PNG graphs: $PNG\n\n";
 
 $now = time;
